/***************************************************************************
                         ribfile.h  -  description
                            -------------------
   begin                : Sun Aug 20 2000
   copyright            : (C) 2000 by Jon Anderson
   email                : janderson@onelink.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RIBFILE_H
#define RIBFILE_H

#include <Plugins/fileplugin.h>

/**
  *@author Jon Anderson
  */

class RIBFile : public FilePlugin
{
   public:
      RIBFile();
      ~RIBFile();

      void exportData( ofstream & );

   protected:

      void writeMeshAsPointsPolygons( Mesh *m, ofstream &out );
      void writeMeshAsPolygons( Mesh *m, ofstream &out );

      void writeSurface( NurbsSurface *, ofstream & );
      void writeCamera( Camera *, ofstream & );


};

#endif
